@@ -66,9 +66,14 @@ impl DebugMessage {
             }
         }
     }
+
+    #[inline]
+    pub fn as_ptr(&self) -> *mut ffi::GstDebugMessage {
+        self.0.as_ptr()
+    }
 }
 
-#[derive(PartialEq, Eq, Clone, Copy)]
+#[derive(PartialEq, Eq, Clone, Copy, Hash)]
 #[doc(alias = "GstDebugCategory")]
 #[repr(transparent)]
 pub struct DebugCategory(Option<ptr::NonNull<ffi::GstDebugCategory>>);
@@ -530,6 +535,11 @@ impl DebugCategory {
             ))
         }
     }
+
+    #[inline]
+    pub fn as_ptr(&self) -> *mut ffi::GstDebugCategory {
+        self.0.map(|p| p.as_ptr()).unwrap_or(ptr::null_mut())
+    }
 }
 
 unsafe impl Sync for DebugCategory {}
