@@ -8,7 +8,7 @@ use glib::{
     translate::*,
 };
 
-use crate::{Stream, StreamCollection};
+use crate::{ffi, Stream, StreamCollection};
 
 #[derive(Debug)]
 pub struct Iter<'a> {
@@ -28,7 +28,7 @@ impl<'a> Iter<'a> {
     }
 }
 
-impl<'a> Iterator for Iter<'a> {
+impl Iterator for Iter<'_> {
     type Item = Stream;
 
     fn next(&mut self) -> Option<Self::Item> {
@@ -72,7 +72,7 @@ impl<'a> Iterator for Iter<'a> {
     }
 }
 
-impl<'a> DoubleEndedIterator for Iter<'a> {
+impl DoubleEndedIterator for Iter<'_> {
     fn next_back(&mut self) -> Option<Self::Item> {
         if self.idx == self.size {
             return None;
@@ -94,9 +94,9 @@ impl<'a> DoubleEndedIterator for Iter<'a> {
     }
 }
 
-impl<'a> ExactSizeIterator for Iter<'a> {}
+impl ExactSizeIterator for Iter<'_> {}
 
-impl<'a> std::iter::FusedIterator for Iter<'a> {}
+impl std::iter::FusedIterator for Iter<'_> {}
 
 #[derive(Debug, Clone)]
 #[must_use = "The builder must be built to be used"]
@@ -115,6 +115,31 @@ impl StreamCollectionBuilder {
         self
     }
 
+    #[doc(alias = "gst_stream_collection_add_stream")]
+    pub fn stream_if(self, stream: Stream, predicate: bool) -> Self {
+        if predicate {
+            unsafe {
+                ffi::gst_stream_collection_add_stream(
+                    (self.0).to_glib_none().0,
+                    stream.into_glib_ptr(),
+                );
+            }
+
+            self
+        } else {
+            self
+        }
+    }
+
+    #[doc(alias = "gst_stream_collection_add_stream")]
+    pub fn stream_if_some(self, stream: Option<Stream>) -> Self {
+        if let Some(stream) = stream {
+            self.stream(stream)
+        } else {
+            self
+        }
+    }
+
     pub fn streams(self, streams: impl IntoIterator<Item = Stream>) -> Self {
         for stream in streams.into_iter() {
             unsafe {
@@ -128,6 +153,40 @@ impl StreamCollectionBuilder {
         self
     }
 
+    pub fn streams_if(self, streams: impl IntoIterator<Item = Stream>, predicate: bool) -> Self {
+        if predicate {
+            for stream in streams.into_iter() {
+                unsafe {
+                    ffi::gst_stream_collection_add_stream(
+                        (self.0).to_glib_none().0,
+                        stream.into_glib_ptr(),
+                    );
+                }
+            }
+
+            self
+        } else {
+            self
+        }
+    }
+
+    pub fn streams_if_some(self, streams: Option<impl IntoIterator<Item = Stream>>) -> Self {
+        if let Some(streams) = streams {
+            self.streams(streams)
+        } else {
+            self
+        }
+    }
+
+    pub fn streams_if_not_empty(self, streams: impl IntoIterator<Item = Stream>) -> Self {
+        let mut streams = streams.into_iter().peekable();
+        if streams.peek().is_some() {
+            self.streams(streams)
+        } else {
+            self
+        }
+    }
+
     #[must_use = "Building the stream collection without using it has no effect"]
     pub fn build(self) -> StreamCollection {
         self.0
@@ -176,7 +235,7 @@ impl StreamCollection {
             connect_raw(
                 self.as_ptr() as *mut _,
                 signal_name.as_ptr() as *const _,
-                Some(transmute::<_, unsafe extern "C" fn()>(
+                Some(transmute::<*const (), unsafe extern "C" fn()>(
                     stream_notify_trampoline::<F> as *const (),
                 )),
                 Box_::into_raw(f),
@@ -212,11 +271,11 @@ impl<'a> IntoIterator for &'a StreamCollection {
 
 pub struct Debug<'a>(&'a StreamCollection);
 
-impl<'a> fmt::Debug for Debug<'a> {
+impl fmt::Debug for Debug<'_> {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         struct Streams<'a>(&'a StreamCollection);
 
-        impl<'a> fmt::Debug for Streams<'a> {
+        impl fmt::Debug for Streams<'_> {
             fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
                 let mut f = f.debug_list();
 
