@@ -9,7 +9,7 @@ use std::{
 use glib::{ffi::gpointer, subclass::prelude::*, translate::*};
 
 use super::prelude::*;
-use crate::{TaskHandle, TaskPool};
+use crate::{ffi, TaskHandle, TaskPool};
 
 pub trait TaskPoolImpl: GstObjectImpl + Send + Sync {
     // rustdoc-stripper-ignore-next
@@ -53,7 +53,7 @@ unsafe impl<T: TaskPoolImpl> IsSubclassable<T> for TaskPool {
         klass.push = Some(task_pool_push::<T>);
         klass.join = Some(task_pool_join::<T>);
 
-        #[cfg(any(feature = "v1_20", feature = "dox"))]
+        #[cfg(feature = "v1_20")]
         {
             klass.dispose_handle = Some(task_pool_dispose_handle::<T>);
         }
@@ -111,7 +111,11 @@ unsafe extern "C" fn task_pool_push<T: TaskPoolImpl>(
 unsafe extern "C" fn task_pool_join<T: TaskPoolImpl>(ptr: *mut ffi::GstTaskPool, id: gpointer) {
     if id.is_null() {
         let wrap: Borrowed<TaskPool> = from_glib_borrow(ptr);
-        crate::warning!(crate::CAT_RUST, obj: wrap.as_ref(), "Tried to join null handle");
+        crate::warning!(
+            crate::CAT_RUST,
+            obj = wrap.as_ref(),
+            "Tried to join null handle"
+        );
         return;
     }
 
@@ -119,15 +123,19 @@ unsafe extern "C" fn task_pool_join<T: TaskPoolImpl>(ptr: *mut ffi::GstTaskPool,
     handle.join();
 }
 
-#[cfg(any(feature = "v1_20", feature = "dox"))]
-#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+#[cfg(feature = "v1_20")]
+#[cfg_attr(docsrs, doc(cfg(feature = "v1_20")))]
 unsafe extern "C" fn task_pool_dispose_handle<T: TaskPoolImpl>(
     ptr: *mut ffi::GstTaskPool,
     id: gpointer,
 ) {
     if id.is_null() {
         let wrap: Borrowed<TaskPool> = from_glib_borrow(ptr);
-        crate::warning!(crate::CAT_RUST, obj: wrap.as_ref(), "Tried to dispose null handle");
+        crate::warning!(
+            crate::CAT_RUST,
+            obj = wrap.as_ref(),
+            "Tried to dispose null handle"
+        );
         return;
     }
 
@@ -215,7 +223,7 @@ impl Eq for TaskPoolFunction {}
 
 impl PartialOrd for TaskPoolFunction {
     fn partial_cmp(&self, other: &Self) -> Option<std::cmp::Ordering> {
-        self.as_ptr().partial_cmp(&other.as_ptr())
+        Some(self.cmp(other))
     }
 }
 
