@@ -6,7 +6,8 @@ use std::{cell::RefCell, cmp, fmt, rc::Rc};
 
 use glib::{
     translate::{from_glib, ToGlibPtr},
-    Date, SendValue, ToValue,
+    value::{SendValue, ToValue},
+    Date,
 };
 use serde::{
     de,
@@ -38,7 +39,7 @@ macro_rules! ser_opt_tag (
     );
 );
 
-// Note: unlike `Value`s, `Tag`s with  optional `Type` `String` & `Date` values are guarenteed
+// Note: unlike `Value`s, `Tag`s with  optional `Type` `String` & `Date` values are guaranteed
 // to be Non-null and non-empty in the C API. See:
 // https://gitlab.freedesktop.org/gstreamer/gstreamer/blob/d90d771a9a512381315f7694c3a50b152035f3cb/gst/gststructure.c#L810-853
 
@@ -51,7 +52,8 @@ impl<'a> TagValuesSer<'a> {
     }
 }
 
-impl<'a> Serialize for TagValuesSer<'a> {
+impl Serialize for TagValuesSer<'_> {
+    #[allow(clippy::redundant_closure_call)]
     fn serialize<S: Serializer>(&self, serializer: S) -> Result<S::Ok, S::Error> {
         use std::ops::DerefMut;
 
@@ -100,7 +102,7 @@ impl<'a> TagsSer<'a> {
     }
 }
 
-impl<'a> Serialize for TagsSer<'a> {
+impl Serialize for TagsSer<'_> {
     fn serialize<S: Serializer>(&self, serializer: S) -> Result<S::Ok, S::Error> {
         let mut tup = serializer.serialize_tuple(2)?;
         tup.serialize_element(self.0)?;
@@ -110,12 +112,12 @@ impl<'a> Serialize for TagsSer<'a> {
 }
 
 struct TagListSer<'a>(&'a TagListRef);
-impl<'a> Serialize for TagListSer<'a> {
+impl Serialize for TagListSer<'_> {
     fn serialize<S: Serializer>(&self, serializer: S) -> Result<S::Ok, S::Error> {
         let tag_count = self.0.n_tags();
         match tag_count.cmp(&0) {
             cmp::Ordering::Greater => {
-                let mut seq = serializer.serialize_seq(Some(tag_count as usize))?;
+                let mut seq = serializer.serialize_seq(Some(tag_count))?;
                 let tag_list_iter = self.0.iter_generic();
                 for (tag_name, tag_iter) in tag_list_iter {
                     seq.serialize_element(&TagsSer::new(tag_name, tag_iter))?;
@@ -160,7 +162,7 @@ macro_rules! de_opt_tag(
 struct TagValues<'a>(&'a str, &'a mut TagListRef);
 
 struct TagValuesVisitor<'a>(&'a str, &'a mut TagListRef);
-impl<'de, 'a> Visitor<'de> for TagValuesVisitor<'a> {
+impl<'de> Visitor<'de> for TagValuesVisitor<'_> {
     type Value = ();
 
     fn expecting(&self, formatter: &mut fmt::Formatter) -> fmt::Result {
@@ -170,7 +172,7 @@ impl<'de, 'a> Visitor<'de> for TagValuesVisitor<'a> {
     fn visit_seq<A: SeqAccess<'de>>(self, mut seq: A) -> Result<(), A::Error> {
         let tag_type: glib::Type = unsafe {
             let tag_name = self.0.to_glib_none();
-            from_glib(ffi::gst_tag_get_type(tag_name.0))
+            from_glib(crate::ffi::gst_tag_get_type(tag_name.0))
         };
 
         loop {
@@ -216,7 +218,7 @@ impl<'de, 'a> Visitor<'de> for TagValuesVisitor<'a> {
     }
 }
 
-impl<'de, 'a> DeserializeSeed<'de> for TagValues<'a> {
+impl<'de> DeserializeSeed<'de> for TagValues<'_> {
     type Value = ();
 
     fn deserialize<D: Deserializer<'de>>(self, deserializer: D) -> Result<(), D::Error> {
@@ -228,7 +230,7 @@ impl<'de, 'a> DeserializeSeed<'de> for TagValues<'a> {
 struct TagValuesTuple<'a>(&'a mut TagListRef);
 
 struct TagValuesTupleVisitor<'a>(&'a mut TagListRef);
-impl<'de, 'a> Visitor<'de> for TagValuesTupleVisitor<'a> {
+impl<'de> Visitor<'de> for TagValuesTupleVisitor<'_> {
     type Value = ();
 
     fn expecting(&self, formatter: &mut fmt::Formatter) -> fmt::Result {
@@ -246,7 +248,7 @@ impl<'de, 'a> Visitor<'de> for TagValuesTupleVisitor<'a> {
     }
 }
 
-impl<'de, 'a> DeserializeSeed<'de> for TagValuesTuple<'a> {
+impl<'de> DeserializeSeed<'de> for TagValuesTuple<'_> {
     type Value = ();
 
     fn deserialize<D: Deserializer<'de>>(self, deserializer: D) -> Result<(), D::Error> {
@@ -461,7 +463,7 @@ mod tests {
             120 * ClockTime::SECOND,
         );
         assert_eq!(tags.index::<Bitrate>(0).unwrap().get(), 96_000);
-        assert!((tags.index::<TrackGain>(0).unwrap().get() - 1f64).abs() < std::f64::EPSILON);
+        assert!((tags.index::<TrackGain>(0).unwrap().get() - 1f64).abs() < f64::EPSILON);
         assert_eq!(
             tags.index::<Date>(0).unwrap().get(),
             glib::Date::from_dmy(28, glib::DateMonth::May, 2018).unwrap()
@@ -497,7 +499,7 @@ mod tests {
         assert_eq!(tags.index::<Title>(0).unwrap().get(), "a title");
         assert_eq!(tags.index::<Title>(1).unwrap().get(), "another title");
         assert_eq!(tags.index::<Bitrate>(0).unwrap().get(), 96_000);
-        assert!((tags.index::<TrackGain>(0).unwrap().get() - 1f64).abs() < std::f64::EPSILON);
+        assert!((tags.index::<TrackGain>(0).unwrap().get() - 1f64).abs() < f64::EPSILON);
         assert_eq!(
             tags.index::<Date>(0).unwrap().get(),
             glib::Date::from_dmy(28, glib::DateMonth::May, 2018).unwrap()
@@ -573,7 +575,7 @@ mod tests {
             (tags_de.index::<TrackGain>(0).unwrap().get()
                 - tags.index::<TrackGain>(0).unwrap().get())
             .abs()
-                < std::f64::EPSILON
+                < f64::EPSILON
         );
         assert_eq!(
             tags_de.index::<Date>(0).unwrap().get(),
