@@ -2,6 +2,7 @@
 
 use std::{cmp, fmt, ops, slice};
 
+use crate::ffi;
 use glib::{prelude::*, translate::*};
 use num_rational::Rational32;
 
@@ -397,8 +398,19 @@ impl IntRangeType for i32 {
     fn with_step(min: i32, max: i32, step: i32) -> IntRange<Self> {
         skip_assert_initialized!();
 
-        assert!(min <= max);
-        assert!(step > 0);
+        assert!(
+            min < max,
+            "maximum value must be greater than minimum value"
+        );
+        assert!(step > 0, "step size must be greater than zero");
+        assert!(
+            min % step == 0,
+            "minimum value must be evenly dividable by step size"
+        );
+        assert!(
+            max % step == 0,
+            "maximum value must be evenly dividable by step size"
+        );
 
         IntRange { min, max, step }
     }
@@ -415,8 +427,19 @@ impl IntRangeType for i64 {
     fn with_step(min: i64, max: i64, step: i64) -> IntRange<Self> {
         skip_assert_initialized!();
 
-        assert!(min <= max);
-        assert!(step > 0);
+        assert!(
+            min < max,
+            "maximum value must be greater than minimum value"
+        );
+        assert!(step > 0, "step size must be greater than zero");
+        assert!(
+            min % step == 0,
+            "minimum value must be evenly dividable by step size"
+        );
+        assert!(
+            max % step == 0,
+            "maximum value must be evenly dividable by step size"
+        );
 
         IntRange { min, max, step }
     }
@@ -936,8 +959,8 @@ impl glib::types::StaticType for Array {
 #[derive(Debug, Clone)]
 pub struct ArrayRef<'a>(&'a [glib::SendValue]);
 
-unsafe impl<'a> Send for ArrayRef<'a> {}
-unsafe impl<'a> Sync for ArrayRef<'a> {}
+unsafe impl Send for ArrayRef<'_> {}
+unsafe impl Sync for ArrayRef<'_> {}
 
 impl<'a> ArrayRef<'a> {
     pub fn new(values: &'a [glib::SendValue]) -> Self {
@@ -952,7 +975,7 @@ impl<'a> ArrayRef<'a> {
     }
 }
 
-impl<'a> ops::Deref for ArrayRef<'a> {
+impl ops::Deref for ArrayRef<'_> {
     type Target = [glib::SendValue];
 
     #[inline]
@@ -961,7 +984,7 @@ impl<'a> ops::Deref for ArrayRef<'a> {
     }
 }
 
-impl<'a> AsRef<[glib::SendValue]> for ArrayRef<'a> {
+impl AsRef<[glib::SendValue]> for ArrayRef<'_> {
     #[inline]
     fn as_ref(&self) -> &[glib::SendValue] {
         self.as_slice()
@@ -987,7 +1010,7 @@ unsafe impl<'a> glib::value::FromValue<'a> for ArrayRef<'a> {
     }
 }
 
-impl<'a> glib::value::ToValue for ArrayRef<'a> {
+impl glib::value::ToValue for ArrayRef<'_> {
     #[inline]
     fn to_value(&self) -> glib::Value {
         let mut value = glib::Value::for_value_type::<Array>();
@@ -1013,7 +1036,7 @@ impl<'a> From<ArrayRef<'a>> for glib::Value {
     }
 }
 
-impl<'a> glib::types::StaticType for ArrayRef<'a> {
+impl glib::types::StaticType for ArrayRef<'_> {
     #[inline]
     fn static_type() -> glib::types::Type {
         unsafe { from_glib(ffi::gst_value_array_get_type()) }
@@ -1163,8 +1186,8 @@ impl glib::types::StaticType for List {
 #[derive(Debug, Clone)]
 pub struct ListRef<'a>(&'a [glib::SendValue]);
 
-unsafe impl<'a> Send for ListRef<'a> {}
-unsafe impl<'a> Sync for ListRef<'a> {}
+unsafe impl Send for ListRef<'_> {}
+unsafe impl Sync for ListRef<'_> {}
 
 impl<'a> ListRef<'a> {
     pub fn new(values: &'a [glib::SendValue]) -> Self {
@@ -1179,7 +1202,7 @@ impl<'a> ListRef<'a> {
     }
 }
 
-impl<'a> ops::Deref for ListRef<'a> {
+impl ops::Deref for ListRef<'_> {
     type Target = [glib::SendValue];
 
     #[inline]
@@ -1188,7 +1211,7 @@ impl<'a> ops::Deref for ListRef<'a> {
     }
 }
 
-impl<'a> AsRef<[glib::SendValue]> for ListRef<'a> {
+impl AsRef<[glib::SendValue]> for ListRef<'_> {
     #[inline]
     fn as_ref(&self) -> &[glib::SendValue] {
         self.as_slice()
@@ -1214,7 +1237,7 @@ unsafe impl<'a> glib::value::FromValue<'a> for ListRef<'a> {
     }
 }
 
-impl<'a> glib::value::ToValue for ListRef<'a> {
+impl glib::value::ToValue for ListRef<'_> {
     #[inline]
     fn to_value(&self) -> glib::Value {
         let mut value = glib::Value::for_value_type::<List>();
@@ -1240,7 +1263,7 @@ impl<'a> From<ListRef<'a>> for glib::Value {
     }
 }
 
-impl<'a> glib::types::StaticType for ListRef<'a> {
+impl glib::types::StaticType for ListRef<'_> {
     #[inline]
     fn static_type() -> glib::types::Type {
         unsafe { from_glib(ffi::gst_value_list_get_type()) }
@@ -1462,6 +1485,199 @@ impl GstValueExt for glib::Value {
     }
 }
 
+#[doc(hidden)]
+#[macro_export]
+macro_rules! impl_builder_gvalue_extra_setters (
+    (field) => {
+        // rustdoc-stripper-ignore-next
+        /// Sets field `name` to the given inner value if the `predicate` evaluates to `true`.
+        ///
+        /// This has no effect if the `predicate` evaluates to `false`,
+        /// i.e. default or previous value for `name` is kept.
+        #[inline]
+        pub fn field_if(self, name: impl $crate::glib::IntoGStr, value: impl Into<$crate::glib::Value> + Send, predicate: bool) -> Self {
+            if predicate {
+                self.field(name, value)
+            } else {
+                self
+            }
+        }
+
+        // rustdoc-stripper-ignore-next
+        /// Sets field `name` to the given inner value if `value` is `Some`.
+        ///
+        /// This has no effect if the value is `None`, i.e. default or previous value for `name` is kept.
+        #[inline]
+        pub fn field_if_some(self, name: impl $crate::glib::IntoGStr, value: Option<impl Into<$crate::glib::Value> + Send>) -> Self {
+            if let Some(value) = value {
+                self.field(name, value)
+            } else {
+                self
+            }
+        }
+
+        // rustdoc-stripper-ignore-next
+        /// Sets field `name` using the given `ValueType` `V` built from `iter`'s the `Item`s.
+        ///
+        /// Overrides any default or previously defined value for `name`.
+        #[inline]
+        pub fn field_from_iter<V: $crate::glib::value::ValueType + Into<$crate::glib::Value> + FromIterator<$crate::glib::SendValue> + Send>(
+            self,
+            name: impl $crate::glib::IntoGStr,
+            iter: impl IntoIterator<Item = impl $crate::glib::value::ToSendValue>,
+        ) -> Self {
+            let iter = iter.into_iter().map(|item| item.to_send_value());
+            self.field(name, V::from_iter(iter))
+        }
+
+        // rustdoc-stripper-ignore-next
+        /// Sets field `name` using the given `ValueType` `V` built from `iter`'s Item`s,
+        /// if `iter` is not empty.
+        ///
+        /// This has no effect if `iter` is empty, i.e. previous value for `name` is unchanged.
+        #[inline]
+        pub fn field_if_not_empty<V: $crate::glib::value::ValueType + Into<$crate::glib::Value> + FromIterator<$crate::glib::SendValue> + Send>(
+            self,
+            name: impl $crate::glib::IntoGStr,
+            iter: impl IntoIterator<Item = impl $crate::glib::value::ToSendValue>,
+        ) -> Self {
+            let mut iter = iter.into_iter().peekable();
+            if iter.peek().is_some() {
+                let iter = iter.map(|item| item.to_send_value());
+                self.field(name, V::from_iter(iter))
+            } else {
+                self
+            }
+        }
+    };
+
+    (other_field) => {
+        // rustdoc-stripper-ignore-next
+        /// Sets field `name` to the given inner value if the `predicate` evaluates to `true`.
+        ///
+        /// This has no effect if the `predicate` evaluates to `false`,
+        /// i.e. default or previous value for `name` is kept.
+        #[inline]
+        pub fn other_field_if(self, name: &'a str, value: impl $crate::glib::value::ToSendValue, predicate: bool) -> Self {
+            if predicate {
+                self.other_field(name, value)
+            } else {
+                self
+            }
+        }
+
+        // rustdoc-stripper-ignore-next
+        /// Sets field `name` to the given inner value if `value` is `Some`.
+        ///
+        /// This has no effect if the value is `None`, i.e. default or previous value for `name` is kept.
+        #[inline]
+        pub fn other_field_if_some(self, name: &'a str, value: Option<impl $crate::glib::value::ToSendValue>) -> Self {
+            if let Some(value) = value {
+                self.other_field(name, value)
+            } else {
+                self
+            }
+        }
+
+        // rustdoc-stripper-ignore-next
+        /// Sets field `name` using the given `ValueType` `V` built from `iter`'s the `Item`s.
+        ///
+        /// Overrides any default or previously defined value for `name`.
+        #[inline]
+        pub fn other_field_from_iter<V: $crate::glib::value::ValueType + $crate::glib::value::ToSendValue + FromIterator<$crate::glib::SendValue>>(
+            self,
+            name: &'a str,
+            iter: impl IntoIterator<Item = impl $crate::glib::value::ToSendValue>,
+        ) -> Self {
+            let iter = iter.into_iter().map(|item| item.to_send_value());
+            self.other_field(name, V::from_iter(iter))
+        }
+
+        // rustdoc-stripper-ignore-next
+        /// Sets field `name` using the given `ValueType` `V` built from `iter`'s Item`s,
+        /// if `iter` is not empty.
+        ///
+        /// This has no effect if `iter` is empty, i.e. previous value for `name` is unchanged.
+        #[inline]
+        pub fn other_field_if_not_empty<V: $crate::glib::value::ValueType + $crate::glib::value::ToSendValue + FromIterator<$crate::glib::SendValue>>(
+            self,
+            name: &'a str,
+            iter: impl IntoIterator<Item = impl $crate::glib::value::ToSendValue>,
+        ) -> Self {
+            let mut iter = iter.into_iter().peekable();
+            if iter.peek().is_some() {
+                let iter = iter.map(|item| item.to_send_value());
+                self.other_field(name, V::from_iter(iter))
+            } else {
+                self
+            }
+        }
+     };
+
+    (property) => {
+        // rustdoc-stripper-ignore-next
+        /// Sets property `name` to the given inner value if the `predicate` evaluates to `true`.
+        ///
+        /// This has no effect if the `predicate` evaluates to `false`,
+        /// i.e. default or previous value for `name` is kept.
+        #[inline]
+        pub fn property_if(self, name: &'a str, value: impl Into<$crate::glib::Value> + 'a, predicate: bool) -> Self {
+            if predicate {
+                self.property(name, value)
+            } else {
+                self
+            }
+        }
+
+        // rustdoc-stripper-ignore-next
+        /// Sets property `name` to the given inner value if `value` is `Some`.
+        ///
+        /// This has no effect if the value is `None`, i.e. default or previous value for `name` is kept.
+        #[inline]
+        pub fn property_if_some(self, name: &'a str, value: Option<impl Into<$crate::glib::Value> + 'a>) -> Self {
+            if let Some(value) = value {
+                self.property(name, value)
+            } else {
+                self
+            }
+        }
+
+        // rustdoc-stripper-ignore-next
+        /// Sets property `name` using the given `ValueType` `V` built from `iter`'s the `Item`s.
+        ///
+        /// Overrides any default or previously defined value for `name`.
+        #[inline]
+        pub fn property_from_iter<V: $crate::glib::value::ValueType + Into<$crate::glib::Value> + FromIterator<$crate::glib::SendValue>>(
+            self,
+            name: &'a str,
+            iter: impl IntoIterator<Item = impl $crate::glib::value::ToSendValue>,
+        ) -> Self {
+            let iter = iter.into_iter().map(|item| item.to_send_value());
+            self.property(name, V::from_iter(iter))
+        }
+
+        // rustdoc-stripper-ignore-next
+        /// Sets property `name` using the given `ValueType` `V` built from `iter`'s Item`s,
+        /// if `iter` is not empty.
+        ///
+        /// This has no effect if `iter` is empty, i.e. previous value for `name` is unchanged.
+        #[inline]
+        pub fn property_if_not_empty<V: $crate::glib::value::ValueType + Into<$crate::glib::Value> + FromIterator<$crate::glib::SendValue>>(
+            self,
+            name: &'a str,
+            iter: impl IntoIterator<Item = impl $crate::glib::value::ToSendValue>,
+        ) -> Self {
+            let mut iter = iter.into_iter().peekable();
+            if iter.peek().is_some() {
+                let iter = iter.map(|item| item.to_send_value());
+                self.property(name, V::from_iter(iter))
+            } else {
+                self
+            }
+        }
+     };
+);
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -1486,7 +1702,77 @@ mod tests {
 
         // Type inference should figure out the type
         let _r1 = crate::IntRange::new(1i32, 2i32);
-        let _r2 = crate::IntRange::with_step(2i64, 3i64, 4i64);
+        let _r2 = crate::IntRange::with_step(2i64, 10i64, 2i64);
+        let _r3 = crate::IntRange::with_step(0i64, 6i64, 3i64);
+    }
+
+    #[test]
+    #[should_panic(expected = "step size must be greater than zero")]
+    fn test_int_range_constructor_step0() {
+        crate::init().unwrap();
+        let _r = crate::IntRange::with_step(0i32, 2i32, 0i32);
+    }
+
+    #[test]
+    #[should_panic(expected = "maximum value must be greater than minimum value")]
+    fn test_int_range_constructor_max_min() {
+        crate::init().unwrap();
+        let _r = crate::IntRange::with_step(4i32, 2i32, 2i32);
+    }
+
+    #[test]
+    #[should_panic(expected = "maximum value must be greater than minimum value")]
+    fn test_int_range_constructor_max_eq_min() {
+        crate::init().unwrap();
+        let _r = crate::IntRange::with_step(4i32, 4i32, 2i32);
+    }
+
+    #[test]
+    #[should_panic(expected = "minimum value must be evenly dividable by step size")]
+    fn test_int_range_constructor_bad_step() {
+        crate::init().unwrap();
+        let _r = crate::IntRange::with_step(1i32, 10i32, 2i32);
+    }
+
+    #[test]
+    #[should_panic(expected = "maximum value must be evenly dividable by step size")]
+    fn test_int_range_constructor_bad_step_max() {
+        crate::init().unwrap();
+        let _r = crate::IntRange::with_step(0i32, 10i32, 3i32);
+    }
+
+    #[test]
+    #[should_panic(expected = "step size must be greater than zero")]
+    fn test_int_range_constructor_step0_i64() {
+        crate::init().unwrap();
+        let _r = crate::IntRange::with_step(0i64, 2i64, 0i64);
+    }
+
+    #[test]
+    #[should_panic(expected = "maximum value must be greater than minimum value")]
+    fn test_int_range_constructor_max_min_i64() {
+        crate::init().unwrap();
+        let _r = crate::IntRange::with_step(4i64, 2i64, 2i64);
+    }
+
+    #[test]
+    #[should_panic(expected = "maximum value must be greater than minimum value")]
+    fn test_int_range_constructor_max_eq_min_i64() {
+        crate::init().unwrap();
+        let _r = crate::IntRange::with_step(4i64, 4i64, 2i64);
+    }
+
+    #[test]
+    #[should_panic(expected = "minimum value must be evenly dividable by step size")]
+    fn test_int_range_constructor_bad_step_i64() {
+        crate::init().unwrap();
+        let _r = crate::IntRange::with_step(1i64, 10i64, 2i64);
+    }
+    #[test]
+    #[should_panic(expected = "maximum value must be evenly dividable by step size")]
+    fn test_int_range_constructor_bad_step_max_i64() {
+        crate::init().unwrap();
+        let _r = crate::IntRange::with_step(0i64, 10i64, 3i64);
     }
 
     #[test]
